"use client"
import { Input } from "@/components/ui/input";
import { CellContext } from "@tanstack/react-table";
import { updateField } from "app/lib/update";
import { useState } from "react";
import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { toast } from "@/components/ui/use-toast";
import { Form, FormControl, FormField, FormItem, FormMessage } from "@/components/ui/form";
import TitleContainer from "app/ui/titleContainer";

export function TextInputCell(props: CellContext<any, any>) {
  const [isActive, setIsActive] = useState(false)

  const table = props.table.options.meta.tableName
  const id = props.row.original.id
  const column = props.column.id
  const pathname = props.table.options.meta.pathname
  const value = props.cell.getValue()
  const formSchema = props.column.columnDef.meta.formSchema.pick({ [column]: true })

  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      [column]: props.cell.getValue()
    },
  })

  async function onSubmit(value: z.infer<typeof formSchema>) {
    toast({
      title: "You submitted the following values:",
      description: (
        <pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
          <code className="text-white">{JSON.stringify(value, null, 2)}</code>
        </pre>
      ),
    })
    const res = await updateField({
      id,
      table,
      datum: value[column],
      column,
      pathname
    })
    setIsActive(false)
  }

  function onErrors(errors) {
    toast({
      title: "You have errors",
      description: (
        <pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
          <code className="text-white">{JSON.stringify(errors, null, 2)}</code>
        </pre>
      ),
    })
    console.log(JSON.stringify(errors))
  }
  return (
    <div
      onDoubleClick={() => setIsActive(prev => !prev)}
      className="w-full h-fit flex items-center justify-left"
      tabIndex={0}
      onKeyDown={e => {
        if (e.code === "Enter" && !isActive) {
          e.preventDefault()
          setIsActive(true)
        }
      }}
    >
      {isActive ?
        <Form {...form}>
          <form onSubmit={form.handleSubmit(onSubmit, onErrors)}
          >
            <FormField
              control={form.control}
              name={column}
              render={({ field }) => (
                <FormItem
                  onBlur={() => setIsActive(false)}
                >
                  <FormControl
                  >
                    <Input
                      className="w-full"
                      type="text"
                      autoFocus={true}
                      {...field}
                    />
                  </FormControl>
                  <FormMessage />
                </FormItem>
              )}
            />

          </form>
        </Form>
        : <TitleContainer>{props.cell.getValue()}</TitleContainer>
      }
    </div >
  )
}
